@@ -24,6 +24,7 @@ __all__ = (
     "AttachmentTypeType",
     "ChangeActionType",
     "ChangeSetStateType",
+    "ChangeStatusType",
     "ChangeTypeType",
     "ConnectPeerAssociationStateType",
     "ConnectPeerStateType",
@@ -37,6 +38,7 @@ __all__ = (
     "DeviceStateType",
     "GetConnectPeerAssociationsPaginatorName",
     "GetConnectionsPaginatorName",
+    "GetCoreNetworkChangeEventsPaginatorName",
     "GetCoreNetworkChangeSetPaginatorName",
     "GetCustomerGatewayAssociationsPaginatorName",
     "GetDevicesPaginatorName",
@@ -56,6 +58,9 @@ __all__ = (
     "ListConnectPeersPaginatorName",
     "ListCoreNetworkPolicyVersionsPaginatorName",
     "ListCoreNetworksPaginatorName",
+    "ListPeeringsPaginatorName",
+    "PeeringStateType",
+    "PeeringTypeType",
     "RouteAnalysisCompletionReasonCodeType",
     "RouteAnalysisCompletionResultCodeType",
     "RouteAnalysisStatusType",
@@ -84,7 +89,7 @@ AttachmentStateType = Literal[
     "REJECTED",
     "UPDATING",
 ]
-AttachmentTypeType = Literal["CONNECT", "SITE_TO_SITE_VPN", "VPC"]
+AttachmentTypeType = Literal["CONNECT", "SITE_TO_SITE_VPN", "TRANSIT_GATEWAY_ROUTE_TABLE", "VPC"]
 ChangeActionType = Literal["ADD", "MODIFY", "REMOVE"]
 ChangeSetStateType = Literal[
     "EXECUTING",
@@ -94,12 +99,17 @@ ChangeSetStateType = Literal[
     "PENDING_GENERATION",
     "READY_TO_EXECUTE",
 ]
+ChangeStatusType = Literal["COMPLETE", "FAILED", "IN_PROGRESS", "NOT_STARTED"]
 ChangeTypeType = Literal[
     "ATTACHMENT_MAPPING",
+    "ATTACHMENT_POLICIES_CONFIGURATION",
     "ATTACHMENT_ROUTE_PROPAGATION",
     "ATTACHMENT_ROUTE_STATIC",
+    "CORE_NETWORK_CONFIGURATION",
     "CORE_NETWORK_EDGE",
     "CORE_NETWORK_SEGMENT",
+    "SEGMENTS_CONFIGURATION",
+    "SEGMENT_ACTIONS_CONFIGURATION",
 ]
 ConnectPeerAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 ConnectPeerStateType = Literal["AVAILABLE", "CREATING", "DELETING", "FAILED"]
@@ -113,6 +123,7 @@ DescribeGlobalNetworksPaginatorName = Literal["describe_global_networks"]
 DeviceStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 GetConnectPeerAssociationsPaginatorName = Literal["get_connect_peer_associations"]
 GetConnectionsPaginatorName = Literal["get_connections"]
+GetCoreNetworkChangeEventsPaginatorName = Literal["get_core_network_change_events"]
 GetCoreNetworkChangeSetPaginatorName = Literal["get_core_network_change_set"]
 GetCustomerGatewayAssociationsPaginatorName = Literal["get_customer_gateway_associations"]
 GetDevicesPaginatorName = Literal["get_devices"]
@@ -134,6 +145,9 @@ ListAttachmentsPaginatorName = Literal["list_attachments"]
 ListConnectPeersPaginatorName = Literal["list_connect_peers"]
 ListCoreNetworkPolicyVersionsPaginatorName = Literal["list_core_network_policy_versions"]
 ListCoreNetworksPaginatorName = Literal["list_core_networks"]
+ListPeeringsPaginatorName = Literal["list_peerings"]
+PeeringStateType = Literal["AVAILABLE", "CREATING", "DELETING", "FAILED"]
+PeeringTypeType = Literal["TRANSIT_GATEWAY"]
 RouteAnalysisCompletionReasonCodeType = Literal[
     "BLACKHOLE_ROUTE_FOR_DESTINATION_FOUND",
     "CYCLIC_PATH_DETECTED",
@@ -191,6 +205,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -231,7 +246,10 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -267,6 +285,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -308,6 +327,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -334,12 +354,14 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -361,6 +383,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -386,6 +409,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -396,11 +420,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -446,6 +472,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -484,6 +511,7 @@ PaginatorName = Literal[
     "describe_global_networks",
     "get_connect_peer_associations",
     "get_connections",
+    "get_core_network_change_events",
     "get_core_network_change_set",
     "get_customer_gateway_associations",
     "get_devices",
@@ -500,4 +528,5 @@ PaginatorName = Literal[
     "list_connect_peers",
     "list_core_network_policy_versions",
     "list_core_networks",
+    "list_peerings",
 ]
