@@ -13,6 +13,7 @@ Usage::
         DescribeGlobalNetworksPaginator,
         GetConnectPeerAssociationsPaginator,
         GetConnectionsPaginator,
+        GetCoreNetworkChangeEventsPaginator,
         GetCoreNetworkChangeSetPaginator,
         GetCustomerGatewayAssociationsPaginator,
         GetDevicesPaginator,
@@ -29,6 +30,7 @@ Usage::
         ListConnectPeersPaginator,
         ListCoreNetworkPolicyVersionsPaginator,
         ListCoreNetworksPaginator,
+        ListPeeringsPaginator,
     )
 
     session = Session()
@@ -37,6 +39,7 @@ Usage::
     describe_global_networks_paginator: DescribeGlobalNetworksPaginator = client.get_paginator("describe_global_networks")
     get_connect_peer_associations_paginator: GetConnectPeerAssociationsPaginator = client.get_paginator("get_connect_peer_associations")
     get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
+    get_core_network_change_events_paginator: GetCoreNetworkChangeEventsPaginator = client.get_paginator("get_core_network_change_events")
     get_core_network_change_set_paginator: GetCoreNetworkChangeSetPaginator = client.get_paginator("get_core_network_change_set")
     get_customer_gateway_associations_paginator: GetCustomerGatewayAssociationsPaginator = client.get_paginator("get_customer_gateway_associations")
     get_devices_paginator: GetDevicesPaginator = client.get_paginator("get_devices")
@@ -53,18 +56,20 @@ Usage::
     list_connect_peers_paginator: ListConnectPeersPaginator = client.get_paginator("list_connect_peers")
     list_core_network_policy_versions_paginator: ListCoreNetworkPolicyVersionsPaginator = client.get_paginator("list_core_network_policy_versions")
     list_core_networks_paginator: ListCoreNetworksPaginator = client.get_paginator("list_core_networks")
+    list_peerings_paginator: ListPeeringsPaginator = client.get_paginator("list_peerings")
     ```
 """
+import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
-from .literals import AttachmentStateType, AttachmentTypeType
+from .literals import AttachmentStateType, AttachmentTypeType, PeeringStateType
 from .type_defs import (
     DescribeGlobalNetworksResponseTypeDef,
     GetConnectionsResponseTypeDef,
     GetConnectPeerAssociationsResponseTypeDef,
+    GetCoreNetworkChangeEventsResponseTypeDef,
     GetCoreNetworkChangeSetResponseTypeDef,
     GetCustomerGatewayAssociationsResponseTypeDef,
     GetDevicesResponseTypeDef,
@@ -81,13 +86,21 @@ from .type_defs import (
     ListConnectPeersResponseTypeDef,
     ListCoreNetworkPolicyVersionsResponseTypeDef,
     ListCoreNetworksResponseTypeDef,
+    ListPeeringsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = (
     "DescribeGlobalNetworksPaginator",
     "GetConnectPeerAssociationsPaginator",
     "GetConnectionsPaginator",
+    "GetCoreNetworkChangeEventsPaginator",
     "GetCoreNetworkChangeSetPaginator",
     "GetCustomerGatewayAssociationsPaginator",
     "GetDevicesPaginator",
@@ -104,6 +117,7 @@ __all__ = (
     "ListConnectPeersPaginator",
     "ListCoreNetworkPolicyVersionsPaginator",
     "ListCoreNetworksPaginator",
+    "ListPeeringsPaginator",
 )
 
 
@@ -117,7 +131,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeGlobalNetworksPaginator(Boto3Paginator):
+class DescribeGlobalNetworksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#describeglobalnetworkspaginator)
@@ -127,7 +141,7 @@ class DescribeGlobalNetworksPaginator(Boto3Paginator):
         self,
         *,
         GlobalNetworkIds: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeGlobalNetworksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks.paginate)
@@ -135,7 +149,7 @@ class DescribeGlobalNetworksPaginator(Boto3Paginator):
         """
 
 
-class GetConnectPeerAssociationsPaginator(Boto3Paginator):
+class GetConnectPeerAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnectPeerAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getconnectpeerassociationspaginator)
@@ -146,7 +160,7 @@ class GetConnectPeerAssociationsPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         ConnectPeerIds: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetConnectPeerAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnectPeerAssociations.paginate)
@@ -154,7 +168,7 @@ class GetConnectPeerAssociationsPaginator(Boto3Paginator):
         """
 
 
-class GetConnectionsPaginator(Boto3Paginator):
+class GetConnectionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getconnectionspaginator)
@@ -166,7 +180,7 @@ class GetConnectionsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         ConnectionIds: Sequence[str] = ...,
         DeviceId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetConnectionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections.paginate)
@@ -174,7 +188,26 @@ class GetConnectionsPaginator(Boto3Paginator):
         """
 
 
-class GetCoreNetworkChangeSetPaginator(Boto3Paginator):
+class GetCoreNetworkChangeEventsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCoreNetworkChangeEvents)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getcorenetworkchangeeventspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        CoreNetworkId: str,
+        PolicyVersionId: int,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[GetCoreNetworkChangeEventsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCoreNetworkChangeEvents.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getcorenetworkchangeeventspaginator)
+        """
+
+
+class GetCoreNetworkChangeSetPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCoreNetworkChangeSet)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getcorenetworkchangesetpaginator)
@@ -185,7 +218,7 @@ class GetCoreNetworkChangeSetPaginator(Boto3Paginator):
         *,
         CoreNetworkId: str,
         PolicyVersionId: int,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetCoreNetworkChangeSetResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCoreNetworkChangeSet.paginate)
@@ -193,7 +226,7 @@ class GetCoreNetworkChangeSetPaginator(Boto3Paginator):
         """
 
 
-class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
+class GetCustomerGatewayAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getcustomergatewayassociationspaginator)
@@ -204,7 +237,7 @@ class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         CustomerGatewayArns: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetCustomerGatewayAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations.paginate)
@@ -212,7 +245,7 @@ class GetCustomerGatewayAssociationsPaginator(Boto3Paginator):
         """
 
 
-class GetDevicesPaginator(Boto3Paginator):
+class GetDevicesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getdevicespaginator)
@@ -224,7 +257,7 @@ class GetDevicesPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         DeviceIds: Sequence[str] = ...,
         SiteId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetDevicesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices.paginate)
@@ -232,7 +265,7 @@ class GetDevicesPaginator(Boto3Paginator):
         """
 
 
-class GetLinkAssociationsPaginator(Boto3Paginator):
+class GetLinkAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getlinkassociationspaginator)
@@ -244,7 +277,7 @@ class GetLinkAssociationsPaginator(Boto3Paginator):
         GlobalNetworkId: str,
         DeviceId: str = ...,
         LinkId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetLinkAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations.paginate)
@@ -252,7 +285,7 @@ class GetLinkAssociationsPaginator(Boto3Paginator):
         """
 
 
-class GetLinksPaginator(Boto3Paginator):
+class GetLinksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getlinkspaginator)
@@ -266,7 +299,7 @@ class GetLinksPaginator(Boto3Paginator):
         SiteId: str = ...,
         Type: str = ...,
         Provider: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetLinksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks.paginate)
@@ -274,7 +307,7 @@ class GetLinksPaginator(Boto3Paginator):
         """
 
 
-class GetNetworkResourceCountsPaginator(Boto3Paginator):
+class GetNetworkResourceCountsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResourceCounts)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getnetworkresourcecountspaginator)
@@ -285,7 +318,7 @@ class GetNetworkResourceCountsPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         ResourceType: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetNetworkResourceCountsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResourceCounts.paginate)
@@ -293,7 +326,7 @@ class GetNetworkResourceCountsPaginator(Boto3Paginator):
         """
 
 
-class GetNetworkResourceRelationshipsPaginator(Boto3Paginator):
+class GetNetworkResourceRelationshipsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResourceRelationships)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getnetworkresourcerelationshipspaginator)
@@ -309,7 +342,7 @@ class GetNetworkResourceRelationshipsPaginator(Boto3Paginator):
         AccountId: str = ...,
         ResourceType: str = ...,
         ResourceArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetNetworkResourceRelationshipsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResourceRelationships.paginate)
@@ -317,7 +350,7 @@ class GetNetworkResourceRelationshipsPaginator(Boto3Paginator):
         """
 
 
-class GetNetworkResourcesPaginator(Boto3Paginator):
+class GetNetworkResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getnetworkresourcespaginator)
@@ -333,7 +366,7 @@ class GetNetworkResourcesPaginator(Boto3Paginator):
         AccountId: str = ...,
         ResourceType: str = ...,
         ResourceArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetNetworkResourcesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkResources.paginate)
@@ -341,7 +374,7 @@ class GetNetworkResourcesPaginator(Boto3Paginator):
         """
 
 
-class GetNetworkTelemetryPaginator(Boto3Paginator):
+class GetNetworkTelemetryPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkTelemetry)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getnetworktelemetrypaginator)
@@ -357,7 +390,7 @@ class GetNetworkTelemetryPaginator(Boto3Paginator):
         AccountId: str = ...,
         ResourceType: str = ...,
         ResourceArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetNetworkTelemetryResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetNetworkTelemetry.paginate)
@@ -365,7 +398,7 @@ class GetNetworkTelemetryPaginator(Boto3Paginator):
         """
 
 
-class GetSitesPaginator(Boto3Paginator):
+class GetSitesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#getsitespaginator)
@@ -376,7 +409,7 @@ class GetSitesPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         SiteIds: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetSitesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites.paginate)
@@ -384,7 +417,7 @@ class GetSitesPaginator(Boto3Paginator):
         """
 
 
-class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
+class GetTransitGatewayConnectPeerAssociationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#gettransitgatewayconnectpeerassociationspaginator)
@@ -395,7 +428,7 @@ class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         TransitGatewayConnectPeerArns: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetTransitGatewayConnectPeerAssociationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations.paginate)
@@ -403,7 +436,7 @@ class GetTransitGatewayConnectPeerAssociationsPaginator(Boto3Paginator):
         """
 
 
-class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
+class GetTransitGatewayRegistrationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#gettransitgatewayregistrationspaginator)
@@ -414,7 +447,7 @@ class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
         *,
         GlobalNetworkId: str,
         TransitGatewayArns: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetTransitGatewayRegistrationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations.paginate)
@@ -422,7 +455,7 @@ class GetTransitGatewayRegistrationsPaginator(Boto3Paginator):
         """
 
 
-class ListAttachmentsPaginator(Boto3Paginator):
+class ListAttachmentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListAttachments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listattachmentspaginator)
@@ -435,7 +468,7 @@ class ListAttachmentsPaginator(Boto3Paginator):
         AttachmentType: AttachmentTypeType = ...,
         EdgeLocation: str = ...,
         State: AttachmentStateType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAttachmentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListAttachments.paginate)
@@ -443,7 +476,7 @@ class ListAttachmentsPaginator(Boto3Paginator):
         """
 
 
-class ListConnectPeersPaginator(Boto3Paginator):
+class ListConnectPeersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListConnectPeers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listconnectpeerspaginator)
@@ -454,7 +487,7 @@ class ListConnectPeersPaginator(Boto3Paginator):
         *,
         CoreNetworkId: str = ...,
         ConnectAttachmentId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListConnectPeersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListConnectPeers.paginate)
@@ -462,14 +495,14 @@ class ListConnectPeersPaginator(Boto3Paginator):
         """
 
 
-class ListCoreNetworkPolicyVersionsPaginator(Boto3Paginator):
+class ListCoreNetworkPolicyVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListCoreNetworkPolicyVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listcorenetworkpolicyversionspaginator)
     """
 
     def paginate(
-        self, *, CoreNetworkId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, CoreNetworkId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCoreNetworkPolicyVersionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListCoreNetworkPolicyVersions.paginate)
@@ -477,16 +510,37 @@ class ListCoreNetworkPolicyVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListCoreNetworksPaginator(Boto3Paginator):
+class ListCoreNetworksPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListCoreNetworks)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listcorenetworkspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListCoreNetworksResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListCoreNetworks.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listcorenetworkspaginator)
         """
+
+
+class ListPeeringsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListPeerings)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listpeeringspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        CoreNetworkId: str = ...,
+        PeeringType: Literal["TRANSIT_GATEWAY"] = ...,
+        EdgeLocation: str = ...,
+        State: PeeringStateType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPeeringsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Paginator.ListPeerings.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators/#listpeeringspaginator)
+        """
